@@ -197,13 +197,16 @@ class _CreateLoadQuantiles(DoFn):
 
             pickup_state = row["pickup_state"]
             dropoff_state = row["dropoff_state"]
+            if row["equipment_type_list"]:
 
-            if "REEFER" in row["equipment_type_list"]:
-                equipment = "reefer"
-            elif "STEPDECK" in row["equipment_type_list"] or "FLATBED" in row["equipment_type_list"]:
-                equipment = "flatbed"
-            elif "VAN" in row["equipment_type_list"]:
-                equipment = "van"
+                if "REEFER" in row["equipment_type_list"]:
+                    equipment = "reefer"
+                elif "STEPDECK" in row["equipment_type_list"] or "FLATBED" in row["equipment_type_list"]:
+                    equipment = "flatbed"
+                elif "VAN" in row["equipment_type_list"]:
+                    equipment = "van"
+                else:
+                    equipment = "ALL"
             else:
                 equipment = "ALL"
 
